@@ -9,10 +9,10 @@ ResolvingParser that additionally resolves any $ref references.
 """
 
 __author__ = 'Jens Finkhaeuser'
-__copyright__ = 'Copyright (c) 2016-2018 Jens Finkhaeuser'
+__copyright__ = 'Copyright (c) 2016-2020 Jens Finkhaeuser'
 __license__ = 'MIT +no-false-attribs'
 __all__ = ('util', 'mixins', 'cli', 'convert')
-__version__ = '0.16.2'
+__version__ = '0.18.3'
 
 
 # Define our own error class
@@ -61,10 +61,13 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
       the parse function to be invoked.
     :param str backend: [optional] one of 'flex', 'swagger-spec-validator' or
       'openapi-spec-validator'.
-      Determines the validation backend to use. Defaults to 'flex'.
+      Determines the validation backend to use. Defaults to the first installed
+      backend in the ordered list obtained from util.validation_backends().
     :param bool strict: [optional] Applies only to the 'swagger-spec-validator'
       backend. If False, accepts non-String keys by stringifying them before
       validation. Defaults to True.
+    :param str encoding: [optional] For local URLs, use the given file encoding
+      instead of auto-detecting. Defaults to None.
     """
     assert url or spec_string and not (url and spec_string), \
         'You must provide either a URL to read, or a spec string to '\
@@ -114,7 +117,8 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
     # If we have a file name, we need to read that in.
     if self.url and self.url != _PLACEHOLDER_URL:
       from .util.url import fetch_url
-      self.specification = fetch_url(self.url)
+      encoding = self.options.get('encoding', None)
+      self.specification = fetch_url(self.url, encoding = encoding)
 
     # If we have a spec string, try to parse it.
     if self._spec_string:
@@ -135,10 +139,7 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
 
   def _validate(self):
     # Ensure specification is a mapping
-    try:
-      from collections.abc import Mapping
-    except ImportError:  # Python 2
-      from collections import Mapping
+    from collections.abc import Mapping
     if not isinstance(self.specification, Mapping):
       raise ValidationError('Could not parse specifications!')
 
@@ -183,7 +184,7 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
       stringified = '%d.%d' % (version[0], version[1])
     self.version = '%s %s' % (self.version_name, stringified)
 
-  def _validate_flex(self, spec_version):
+  def _validate_flex(self, spec_version):  # pragma: nocover
     # Set the version independently of whether validation succeeds
     self.__set_version(BaseParser.SPEC_VERSION_2_PREFIX, spec_version)
 
@@ -221,8 +222,8 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
 
       try:
         validate_v3_spec(self.specification)
-      except TypeError as type_ex:  # pragma: nocover
-        raise_from(ValidationError, type_ex)
+      except TypeError as type_ex:
+        raise_from(ValidationError, type_ex, self._strict_warning())
       except JSEValidationError as v3_ex:
         raise_from(ValidationError, v3_ex)
       except RefResolutionError as ref_ex:
@@ -234,12 +235,20 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
       try:
         validate_v2_spec(self.specification)
       except TypeError as type_ex:  # pragma: nocover
-        raise_from(ValidationError, type_ex)
+        raise_from(ValidationError, type_ex, self._strict_warning())
       except JSEValidationError as v2_ex:
         raise_from(ValidationError, v2_ex)
       except RefResolutionError as ref_ex:
         raise_from(ValidationError, ref_ex)
 
+  def _strict_warning(self):
+    """Return a warning if strict mode is off."""
+    if self.options.get('strict', True):
+      return ('Strict mode enabled (the default), so this could be due to an '
+          'integer key, such as an HTTP status code.')
+    return ('Strict mode disabled. Prance cannot help you narrow this further '
+        'down, sorry.')
+
 
 class ResolvingParser(BaseParser):
   """The ResolvingParser extends BaseParser with resolving references."""
@@ -251,7 +260,12 @@ class ResolvingParser(BaseParser):
     Resolves JSON pointers/references (i.e. '$ref' keys) before validating the
     specs. The implication is that self.specfication is fully resolved, and
     does not contain any references.
+
+    Additional parameters, see :py::class:`util.RefResolver`.
     """
+    # Create a reference cache
+    self.__reference_cache = {}
+
     BaseParser.__init__(
         self,
         url = url,
@@ -267,7 +281,16 @@ class ResolvingParser(BaseParser):
     # http://swagger.io/specification/#referenceObject
     # We therefore use our own resolver first, and validate later.
     from .util.resolver import RefResolver
-    resolver = RefResolver(self.specification, self.url)
+    forward_arg_names = ('encoding', 'recursion_limit',
+            'recursion_limit_handler', 'resolve_types')
+    forward_args = {
+      k: v for (k, v) in self.options.items() if k in forward_arg_names
+    }
+    resolver = RefResolver(
+        self.specification, self.url,
+        reference_cache = self.__reference_cache,
+        **forward_args
+      )
     resolver.resolve_references()
     self.specification = resolver.specs
 
