@@ -51,12 +51,12 @@ def test_filename_or_spec():
     BaseParser('', '')
 
 
-@pytest.mark.skipif(none_of('openapi_spec_validator', 'swagger_spec_validator', 'flex'), reason='Backends missing.')
+@pytest.mark.skipif(none_of('openapi-spec-validator', 'swagger-spec-validator', 'flex'), reason='Backends missing.')
 def test_load_and_parse_valid(petstore_parser):
   assert petstore_parser.specification, 'No specs loaded!'
 
 
-@pytest.mark.skipif(none_of('openapi_spec_validator', 'swagger_spec_validator', 'flex'), reason='Backends missing.')
+@pytest.mark.skipif(none_of('openapi-spec-validator', 'swagger-spec-validator', 'flex'), reason='Backends missing.')
 def test_load_and_parse_lazy():
   parser = BaseParser('tests/specs/petstore.yaml', lazy = True)
   assert parser.specification is None, 'Should not have specs yet!'
@@ -65,17 +65,17 @@ def test_load_and_parse_lazy():
   assert parser.specification, 'No specs loaded!'
 
 
-@pytest.mark.skipif(none_of('openapi_spec_validator', 'swagger_spec_validator', 'flex'), reason='Backends missing.')
+@pytest.mark.skipif(none_of('openapi-spec-validator', 'swagger-spec-validator', 'flex'), reason='Backends missing.')
 def test_yaml_valid(petstore_parser):
   assert petstore_parser.yaml(), 'Did not get YAML representation of specs!'
 
 
-@pytest.mark.skipif(none_of('openapi_spec_validator', 'swagger_spec_validator', 'flex'), reason='Backends missing.')
+@pytest.mark.skipif(none_of('openapi-spec-validator', 'swagger-spec-validator', 'flex'), reason='Backends missing.')
 def test_json_valid(petstore_parser):
   assert petstore_parser.json(), 'Did not get JSON representation of specs!'
 
 
-@pytest.mark.skipif(none_of('openapi_spec_validator', 'swagger_spec_validator', 'flex'), reason='Backends missing.')
+@pytest.mark.skipif(none_of('openapi-spec-validator', 'swagger-spec-validator', 'flex'), reason='Backends missing.')
 def test_cache_specs_mixin(petstore_parser):
   # In order to test the caching, we need to first use either the YAML or the
   # JSON mixin. Let's use YAML, because it's more swagger-ish
@@ -95,7 +95,7 @@ def test_cache_specs_mixin(petstore_parser):
   assert yaml != petstore_parser.yaml(), 'YAML representation did not change!'
 
 
-@pytest.mark.skipif(none_of('openapi_spec_validator', 'swagger_spec_validator', 'flex'), reason='Backends missing.')
+@pytest.mark.skipif(none_of('openapi-spec-validator', 'swagger-spec-validator', 'flex'), reason='Backends missing.')
 def test_relative_urls_from_string(petstore_parser_from_string):
   # This must succeed
   assert petstore_parser_from_string.yaml(), 'Did not get YAML representation of specs!'
